==> tecfy_corev2_package-1.1.49.tar.gz: lib/models/entity/property_file.model.dart <==
part of tecfy_corev2_client_package;

class PropertyFile extends Property {
  late int maxSize;

  // late int maxHeight;
  double? aspectRatioMin;
  double? aspectRatioMax;
  late String allowedExtentions;
  late bool isImage = false;

  PropertyFile(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      width,
      size,
      this.isImage = false})
      : super(
            propertyType: PropertyTypes.File,
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            isRequired: isRequired,
            valueType: ValueTypes.Text,
            width: width,
            size: size);

  PropertyFile.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    maxSize = BaseModel.getIntEx(row['maxSize']) ?? 0;
    aspectRatioMin = row['aspectRatioMin'];
    aspectRatioMax = row['aspectRatioMax'];
    // maxHeight = row['maxHeight'] ?? 0;
    allowedExtentions = row['allowedExtentions'] ?? '';
    isImage = row['isImage'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text('File');
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return 'File';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null) return false;

    return false;
  }
}

==> tecfy_corev2_package-1.1.57.tar.gz: lib/models/entity/property_file.model.dart <==
part of tecfy_corev2_client_package;

class PropertyFile extends Property {
  late int maxSize;

  // late int maxHeight;
  double? aspectRatioMin;
  double? aspectRatioMax;
  late String allowedExtentions;
  late bool isImage = false;

  PropertyFile(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      width,
      size,
      this.isImage = false})
      : super(
            propertyType: PropertyTypes.File,
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            isRequired: isRequired,
            valueType: ValueTypes.Text,
            width: width,
            size: size);

  PropertyFile.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    maxSize = BaseModel.getIntEx(row['maxSize']) ?? 0;
    aspectRatioMin = row['aspectRatioMin'] != null
        ? BaseModel.getDoubleEx(row['aspectRatioMin'])
        : null;
    aspectRatioMax = row['aspectRatioMax'] != null
        ? BaseModel.getDoubleEx(row['aspectRatioMax'])
        : null;
    // maxHeight = row['maxHeight'] ?? 0;
    allowedExtentions = row['allowedExtentions'] ?? '';
    isImage = row['isImage'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text('File');
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return 'File';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null) return false;

    return false;
  }
}
